share_strerror(errornum) -> str

Return a string describing a libcurl share-interface error code.

*errornum* is a ``CURLSHcode`` as returned by share-handle operations.

Corresponds to `curl_share_strerror`_ in libcurl.

.. _curl_share_strerror: https://curl.haxx.se/libcurl/c/curl_share_strerror.html
